#include <TApplication.h>
#include <TGClient.h>
#include <TCanvas.h>
#include <TF1.h>
#include <TRandom.h>
#include <TGButton.h>
#include "MyMainFrame.hh"

ClassImp(MyMainFrame)

MyMainFrame::MyMainFrame(const TGWindow *p,UInt_t w,UInt_t h)
   : TGMainFrame(p,w,h) {

  // Create timer for automatic histo update
  fTimer = new TTimer();
  fTimer->Connect("Timeout()","MyMainFrame",this,"DoDraw()");

  // Creates widgets of the example
  fEcanvas = new TRootEmbeddedCanvas ("Ecanvas",this,200,200);
  AddFrame(fEcanvas, new TGLayoutHints(kLHintsExpandX | 
				       kLHintsExpandY, 10,10,10,1));
  TGHorizontalFrame *hframe=new TGHorizontalFrame(this, 200,40);
  TGTextButton *draw = new TGTextButton(hframe,"&Draw");
  draw->Connect("Clicked()","MyMainFrame",this,"DoDraw()");
  hframe->AddFrame(draw, new TGLayoutHints(kLHintsCenterX,
					   5,5,3,4));
  TGTextButton *exit = new TGTextButton(hframe,"&Exit ",
					"gApplication->Terminate()");
  hframe->AddFrame(exit, new TGLayoutHints(kLHintsCenterX,
					   5,5,3,4));
  AddFrame(hframe,new TGLayoutHints(kLHintsCenterX,2,2,2,2));
  
  // Sets window name and shows the main frame
  SetWindowName("Simple Example");
  MapSubwindows();
  Resize(GetDefaultSize());
  MapWindow();

  // Make initial plot
  DoDraw();

}

void MyMainFrame::DoDraw() {

  // Reset the timer while we process data
  fTimer->Reset();

  // Draws function graphics in randomly choosen interval
  TF1 *f1 = new TF1("f1","sin(x)/x",0,gRandom->Rndm()*10);
  f1->SetLineWidth(3);
  f1->Draw();
  TCanvas *fCanvas = fEcanvas->GetCanvas();
  fCanvas->cd();
  fCanvas->Update();

  // Repeat check after 10 seconds
  printf("Setting timer to 10 secs\n");
  fTimer->Start(10000,kTRUE);

}

MyMainFrame::~MyMainFrame() {
  // Clean up used widgets: frames, buttons, layout hints
  Cleanup();
}
